@@ -22,7 +22,7 @@ class Login(tornado.web.RequestHandler):
         password = self.get_argument('password', '')
         password = '{SHA}' + base64.b64encode(hashlib.sha1(password).digest()) + '\n'
 
-        path = os.path.join(pyaas.root, pyaas.config.get('basic', 'path'))
+        path = os.path.join(pyaas.prefix, pyaas.config.get('basic', 'path'))
         fp = open(path, 'r')
         for line in fp:
             if not line:
